# @open-xchange/vite-plugin-proxy

An OX App Suite specific proxy for development purposes. Can connect multiple vite-dev-servers with [@open-xchange/vite-plugin-ox-manifests](https://gitlab.open-xchange.com/frontend/vite-plugin-ox-manifests) plugins.

## Install

```bash
npm install "@open-xchange/vite-plugin-proxy"
yarn add "@open-xchange/vite-plugin-proxy"
```

## Options

You can provide the following options to the plugin:

* proxy `<object>` An object with proxy configurations, where the key need to match the beginning of the path. Usually used to forward /api requests to a backend.
* proxy[key] `<string|regexp>` The key defines which paths should be proxied. Keys starting with `^` will be treated as regular expressions.
* proxy[key].target `<string>` The target where to forward these requests to.
* proxy[key].ws `<boolean>` If ws is true, this will only listen to upgrade events for a websocket. Default: `false`
* proxy[key].rewrite `<function>` A function that receives the path as parameter and returns the new path to proxy.
* proxy[key].prependPath `<string>` A string that is prepended for every request. If prependPath and rewrite are present, the key is first prepended and then rewrite is called.
* frontendURIs `<string[]>` An array of frontend URIs which can either point to other vite-dev-servers or production builds. The entries with lower index have higher priority and overwrite files and manifests from others. This array will automatically contain the current workspace with the highest priority.
* logLevel `<string>` One of `fatal`, `error`, `warn`, `info`, `debug`, `trace`, `silent`. Default: `error`
* secure `<boolean>` Set to false to allow self-signed certificates. Default: `true`

## Example configuration

```js
vitePluginProxy({
  proxy: {
    '/api': {
      target: 'https://path.to.my.middleware/',
      prependPath: '/appsuite',
      rewrite: path => path.replace(/\/v1\//, '/v2/')
    },
    '/socket.io/appsuite': {
      target: `wss://path.to.my.middleware/socket.io/appsuite`,
      ws: true
    }
  },
  frontendURIs: ['https://localhost:3000', 'https://localhost:3001'],
  logLevel: 'info',
  secure: false
}),
```
