import { PROJECT_NAME as name } from './constants.js'
import manifestMiddleware from './middlewares/manifest.js'
import proxyMiddleware from './middlewares/proxy.js'
import proxyFrontendsMiddleware from './middlewares/proxy-frontend.js'
import upgradeMiddleware from './middlewares/upgrade.js'
import detectDevServerMiddleware from './middlewares/detect-dev-server.js'
import logger from './logger.js'

export default function ({ proxy, frontendURIs, logLevel = 'error', secure = true } = {}) {
  logger.level = logLevel

  return {

    enforce: 'pre',

    name,

    async configureServer ({ config: { server: serverConfig }, middlewares, httpServer }) {
      const proxies = Object.entries(proxy || {}).map(([condition, config]) => {
        // prepare proxy config
        const { hostname, protocol, port } = new URL(config.target)
        condition = condition.startsWith('^') ? new RegExp(condition) : condition
        return [condition, {
          ...config,
          hostname,
          protocol,
          port
        }]
      })
      const webProxies = proxies.filter(([c, { ws }]) => ws !== true)
      const wsProxies = proxies.filter(([c, { ws }]) => ws === true)
      const frontendUrls = [].concat(frontendURIs).filter(Boolean).map(uri => new URL(uri))

      middlewares.use(detectDevServerMiddleware({
        httpServer,
        frontendUrls,
        serverConfig
      }))

      middlewares.use(manifestMiddleware({
        frontendUrls,
        secure
      }))

      middlewares.use(proxyMiddleware({
        urls: webProxies,
        secure
      }))

      middlewares.use(proxyFrontendsMiddleware({
        urls: frontendUrls,
        secure
      }))

      httpServer.on('upgrade', upgradeMiddleware({
        urls: wsProxies,
        secure
      }))
    }
  }
}
