import parseurl from 'parseurl'
import * as proxy from '../proxy.js'
import { HttpError } from 'http-errors'
import logger from '../logger.js'
import finalhandler from 'finalhandler'

function mergeManifests (manifests) {
  const manifestsByHash = {}

  manifests.forEach(manifest => {
    const hash = `${manifest.namespace}--${manifest.path}`
    // overwrites existing ones. last wins
    manifestsByHash[hash] = manifest
  })
  return Object.values(manifestsByHash)
}

export default function ({ frontendUrls, secure }) {
  return async function (req, res, next) {
    if (req.headers['proxied-by-ox-proxy']) return next()
    const { path } = parseurl(req)
    if (path !== '/manifests') return next()

    try {
      const responses = await proxy.all(req, res, { urls: frontendUrls, headers: { 'proxied-by-ox-proxy': true }, secure })
      const data = mergeManifests(responses.flat().reverse())

      // merge all manifests
      res.statusCode = 200
      res.setHeader('Content-Type', 'application/json')
      res.write(JSON.stringify(data))
      return res.end()
    } catch (err) {
      const handle = finalhandler(req, res)
      if (err instanceof HttpError) {
        // in case of http-error the proxy explicitedly received a error code
        logger.error(err)
        return handle(err)
      }
      logger.error(err)
      return handle()
    }
  }
}
