import parseurl from 'parseurl'
import { createPath } from '../http.js'
import logger from '../logger.js'
import * as proxy from '../proxy.js'

export default function ({ urls, secure }) {
  return async function (req, socket, head) {
    socket.on('error', (err) => logger.error(err))
    const { path } = parseurl(req)
    for (const [condition, config] of urls) {
      const { hostname, protocol, port } = config
      if (path.startsWith(condition)) {
        logger.info(`Websocket at "${path}" is handled by vite-plugin-proxy`)
        try {
          return await proxy.ws(req, socket, head, { hostname, protocol, port, path: createPath(path, config), secure })
        } catch (err) {
          logger.error(`Upgrade of websocket at "${path}" failed.`)
          logger.error(err)
          return
        }
      }
    }
  }
}
