import { describe, it, afterEach } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import { closeAllServers, createViteServer, getPort } from '../util'
import axios from 'axios'

const __dirname = path.dirname(new URL(import.meta.url).pathname)
const PORT = getPort()

describe('detect dev server', function () {
  afterEach(async function () {
    await closeAllServers()
  })

  it('works', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()]
    }, PORT)

    // need to launch a request to trigger own server detection
    await axios({ baseURL: `http://localhost:${PORT}/index.js` })
  })

  it('works with all hosts config', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()],
      server: {
        host: '0.0.0.0'
      }
    }, PORT)

    // need to launch a request to trigger own server detection
    await axios({ baseURL: `http://localhost:${PORT}/index.js` })
  })

  it('works with all hosts config ipv6', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy()],
      server: {
        host: '::'
      }
    }, PORT)

    // need to launch a request to trigger own server detection
    await axios({ baseURL: `http://localhost:${PORT}/index.js` })
  })
})
