import { createServer } from 'vite'
import express from 'express'

const servers = []

export async function closeAllServers () {
  for (const server of servers) {
    try {
      await server.close()
    } catch (err) {
      // do nothing
    }
  }
  servers.splice(0, servers.length)
}

/**
 * @param {import('vite').UserConfig} options
 */
export async function createViteServer (options, port) {
  const server = await createServer(options)
  servers.push(server)
  return server.listen(port)
}

export async function createExpressServer (port) {
  const app = express()
  return new Promise((resolve) => {
    const server = app.listen(port, () => resolve(app))
    servers.push(server)
  })
}

export function getPort () {
  return (5000 + Math.random() * 5000) >> 0
}
